summaryrefslogtreecommitdiff
path: root/src/MTS_IO_CellularRadio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/MTS_IO_CellularRadio.cpp')
-rw-r--r--src/MTS_IO_CellularRadio.cpp11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/MTS_IO_CellularRadio.cpp b/src/MTS_IO_CellularRadio.cpp
index 8f838b6..2acc064 100644
--- a/src/MTS_IO_CellularRadio.cpp
+++ b/src/MTS_IO_CellularRadio.cpp
@@ -86,6 +86,7 @@ const std::string CellularRadio::KEY_CARRIER("carrier"); //!< Cellular Service
const std::string CellularRadio::VALUE_CARRIER_VERIZON("Verizon");
const std::string CellularRadio::VALUE_CARRIER_AERIS("Aeris");
const std::string CellularRadio::VALUE_CARRIER_SPRINT("Sprint");
+const std::string CellularRadio::VALUE_CARRIER_USCELLULAR("U.S. Cellular");
const std::string CellularRadio::VALUE_CARRIER_ATT("AT&T");
const std::string CellularRadio::VALUE_CARRIER_TMOBILE("T-Mobile");
@@ -1588,7 +1589,7 @@ bool CellularRadio::getCarrierFromFirmware(const std::string& sFirmware, std::st
// "z" = is the product type, i.e. DUAL or SC
// "y" = is the carrier variant
// "x" = is the firmware version
// Telit will do their best to keep the carrier variant as "0" for Sprint, "1" for Aeris, and "2" for Verizon.
const uint32_t CARRIER_INDEX = 1; //y in [zyx]
@@ -1607,14 +1608,18 @@ bool CellularRadio::getCarrierFromFirmware(const std::string& sFirmware, std::st
if(cId == '0') {
sCarrier = VALUE_CARRIER_SPRINT;
bResult = true;
- }
+ } else
if(cId == '1') {
sCarrier = VALUE_CARRIER_AERIS;
bResult = true;
- }
+ } else
if(cId == '2') {
sCarrier = VALUE_CARRIER_VERIZON;
bResult = true;
+ } else
+ if(cId == '3') {
+ sCarrier = VALUE_CARRIER_USCELLULAR;
+ bResult = true;
}
}
}
@@ -1588,7 +1589,7 @@ bool CellularRadio::getCarrierFromFirmware(const std::string& sFirmware, std::st
// "y" = is the carrier variant
// "x" = is the firmware version
- // Telit will do their best to keep the carrier variant as "0" for Sprint, "1" for Aeris, and "2" for Verizon.
+ // Telit will do their best to keep the carrier variant as "0" for Sprint, "1" for Aeris, "2" for Verizon, and "3" for U.S. Cellular.
const uint32_t CARRIER_INDEX = 1; //y in [zyx]